@@ -68,12 +68,21 @@ Scaffold::Handler::Favicon - A handler to handle "favicon.ico" files
         favicon   => 'image.jpeg',
         doc_rootp => 'html'
     },
-    locations => {
-        '/'            => 'App::Main',
-        '/robots.txt'  => 'Scaffold::Handler::Robots',
-        '/favicon.ico' => 'Scaffold::Handler::Favicon',
-        '/static'      => 'Scaffold::Handler::Static',
-    },
+    locations => [
+        {
+            route   => qr{^/$},
+            handler => 'App::Main',
+        },{
+            route   => qr{^/robots.txt$},
+            handler => 'Scaffold::Handler::Robots',
+        },{
+            route   => qr{^/favicon.ico$},
+            handler => 'Scaffold::Handler::Favicon',
+        },{
+            route   => qr{^/static/(.*)$},
+            handler => 'Scaffold::Handler::Static',
+        }
+     ]
  );
 
 =head1 DESCRIPTION
@@ -106,6 +115,7 @@ requests will load the image from cache instead of disk.
  Scaffold::Render
  Scaffold::Render::Default
  Scaffold::Render::TT
+ Scaffold::Routes
  Scaffold::Server
  Scaffold::Session::Manager
  Scaffold::Stash
@@ -125,7 +135,7 @@ requests will load the image from cache instead of disk.
 
 =head1 AUTHOR
 
-Kevin L. Esteb, E<lt>kesteb@wsipc.orgE<gt>
+Kevin L. Esteb, E<lt>kevin@kesteb.usE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
