@@ -43,7 +43,7 @@ Scaffold::Uaf::Rule - A base class for rules.
 =head1 DESCRIPTION
 
 Each rule is a custom-written class that implements some aspect of your site's
-access logic. Rules can choose to grant or deny a request. 
+authorization logic. Rules can choose to grant or deny a request. 
 
  package Sample::Test;
 
@@ -109,11 +109,13 @@ request.
  Scaffold::Render
  Scaffold::Render::Default
  Scaffold::Render::TT
+ Scaffole::Routes
  Scaffold::Server
  Scaffold::Session::Manager
  Scaffold::Stash
  Scaffold::Stash::Controller
  Scaffold::Stash::Cookie
+ Scaffold::Stash::Manager
  Scaffold::Stash::View
  Scaffold::Uaf::Authenticate
  Scaffold::Uaf::AuthorizeFactory
@@ -128,7 +130,7 @@ request.
 
 =head1 AUTHOR
 
-Kevin L. Esteb E<lt>kesteb@wsipc.orgE<gt>.
+Kevin L. Esteb E<lt>kevin@kesteb.usE<gt>.
 
 =head1 COPYRIGHT AND LICENSE
 
